@@ -28,6 +28,16 @@ COLOR_SCHEMES = {
         'disasm_view_unprintable_character_color': QColor(0x80, 0x40, 0x00),
         'disasm_view_unknown_byte_color': QColor(0xf0, 0x00, 0x00),
         'disasm_view_unknown_character_color': QColor(0xf0, 0x00, 0x00),
+        'disasm_view_back_edge_color': QColor(0xf9, 0xd5, 0x77),
+        'disasm_view_true_edge_color': QColor(0x79, 0xcc, 0xcd),
+        'disasm_view_false_edge_color': QColor(0xf1, 0x66, 0x64),
+        'disasm_view_direct_jump_edge_color': QColor(0x56, 0x5a, 0x5c),
+        'disasm_view_exception_edge_color': QColor(0xf9, 0x91, 0x0a),
+        'hex_view_selection_color': QColor(0xFF, 0x00, 0x00),
+        'hex_view_selection_alt_color': QColor(0xA0, 0xA0, 0xA4),
+        'hex_view_data_color': QColor(0x00, 0x00, 0xFF),
+        'hex_view_string_color': QColor(0x00, 0xFF, 0xFF),
+        'hex_view_instruction_color': QColor(0xFF, 0x00, 0xFF),
         'function_table_color': QColor(0x00, 0x00, 0x00),
         'function_table_syscall_color': QColor(0x00, 0x00, 0x80),
         'function_table_plt_color': QColor(0x00, 0x80, 0x00),
@@ -76,22 +86,32 @@ COLOR_SCHEMES = {
         'disasm_view_ir_default_color': QColor(0x80, 0x80, 0x80),
         'disasm_view_label_color': QColor(0x00, 0xaa, 0xff),
         'disasm_view_label_highlight_color': QColor(0x2f, 0x2f, 0x25),
-        'disasm_view_target_addr_color': QColor(0x00, 0x00, 0xff),
+        'disasm_view_target_addr_color': QColor(0x00, 0xaa, 0xff),
         'disasm_view_antitarget_addr_color': QColor(0xff, 0x00, 0x00),
         'disasm_view_node_shadow_color': QColor(0x00, 0x00, 0x00, 0x4b),
         'disasm_view_node_background_color': QColor(0x3c, 0x3c, 0x3c),
         'disasm_view_node_zoomed_out_background_color': QColor(0x64, 0x64, 0x64),
         'disasm_view_node_border_color': QColor(0x50, 0x50, 0x50),
         'disasm_view_node_instruction_selected_background_color': QColor(0x4c, 0x50, 0x58),
-        'disasm_view_node_address_color': QColor(0xe0, 0xe0, 0xe0),
+        'disasm_view_node_address_color': QColor(0x2c, 0xc9, 0x76),
         'disasm_view_node_mnemonic_color': QColor(0xe0, 0xe0, 0xe0),
         'disasm_view_selected_node_border_color': QColor(0x6b, 0x71, 0x7c),
         'disasm_view_printable_byte_color': QColor(0x00, 0x80, 0x40),
         'disasm_view_printable_character_color': QColor(0x00, 0x80, 0x40),
-        'disasm_view_unprintable_byte_color': QColor(0x80, 0x40, 0x00),
-        'disasm_view_unprintable_character_color': QColor(0x80, 0x40, 0x00),
+        'disasm_view_unprintable_byte_color': QColor(0xba, 0xba, 0xba),
+        'disasm_view_unprintable_character_color': QColor(0xba, 0xba, 0xba),
         'disasm_view_unknown_byte_color': QColor(0xf0, 0x00, 0x00),
         'disasm_view_unknown_character_color': QColor(0xf0, 0x00, 0x00),
+        'disasm_view_back_edge_color': QColor(0xf9, 0xd5, 0x77),
+        'disasm_view_true_edge_color': QColor(0x79, 0xcc, 0xcd),
+        'disasm_view_false_edge_color': QColor(0xf1, 0x66, 0x64),
+        'disasm_view_direct_jump_edge_color': QColor(0x56, 0x5a, 0x5c),
+        'disasm_view_exception_edge_color': QColor(0xf9, 0x91, 0x0a),
+        'hex_view_selection_color': QColor(0xFF, 0x00, 0x00),
+        'hex_view_selection_alt_color': QColor(0xA0, 0xA0, 0xA4),
+        'hex_view_data_color': QColor(0x00, 0x00, 0xFF),
+        'hex_view_string_color': QColor(0x00, 0xFF, 0xFF),
+        'hex_view_instruction_color': QColor(0xFF, 0x00, 0xFF),
         'function_table_color': QColor(0xe0, 0xe0, 0xe0),
         'function_table_syscall_color': QColor(0x00, 0x00, 0x80),
         'function_table_plt_color': QColor(0x00, 0x80, 0x00),
