@@ -1,6 +1,5 @@
 
 from .file_toolbar import FileToolbar
-from .states_toolbar import StatesToolbar
-from .analysis_toolbar import AnalysisToolbar
 from .function_table_toolbar import FunctionTableToolbar
 from .nav_toolbar import NavToolbar
+from .simgr_toolbar import SimgrToolbar
